package com.ruoyi.file.service.impl;

import com.ruoyi.file.domain.FilesStorage;
import com.ruoyi.file.mapper.FilesStorageMapper;
import com.ruoyi.file.service.IFilesStorageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 存放表Service业务层处理
 * 
 * @author cmc
 * @date 2022-09-06
 */
@Service
public class FilesStorageServiceImpl implements IFilesStorageService 
{
    @Autowired
    private FilesStorageMapper filesStorageMapper;

    /**
     * 查询存放表
     * 
     * @param id 存放表主键
     * @return 存放表
     */
    @Override
    public FilesStorage selectFilesStorageById(String id)
    {
        return filesStorageMapper.selectFilesStorageById(id);
    }

    /**
     * 查询存放表列表
     * 
     * @param filesStorage 存放表
     * @return 存放表
     */
    @Override
    public List<FilesStorage> selectFilesStorageList(FilesStorage filesStorage)
    {
        return filesStorageMapper.selectFilesStorageList(filesStorage);
    }

    /**
     * 查询存放表列表
     *
     * @param filesStorage 存放表
     * @return 存放表
     */
    @Override
    public List<FilesStorage> selectFilesStorageListE(FilesStorage filesStorage)
    {
        return filesStorageMapper.selectFilesStorageListE(filesStorage);
    }

    /**
     * 新增存放表
     * 
     * @param filesStorage 存放表
     * @return 结果
     */
    @Override
    public int insertFilesStorage(FilesStorage filesStorage)
    {
        return filesStorageMapper.insertFilesStorage(filesStorage);
    }

    /**
     * 修改存放表
     * 
     * @param filesStorage 存放表
     * @return 结果
     */
    @Override
    public int updateFilesStorage(FilesStorage filesStorage)
    {
        return filesStorageMapper.updateFilesStorage(filesStorage);
    }

    /**
     * 批量删除存放表
     * 
     * @param ids 需要删除的存放表主键
     * @return 结果
     */
    @Override
    public int deleteFilesStorageByIds(String[] ids)
    {
        return filesStorageMapper.deleteFilesStorageByIds(ids);
    }

    /**
     * 删除存放表信息
     * 
     * @param id 存放表主键
     * @return 结果
     */
    @Override
    public int deleteFilesStorageById(String id)
    {
        return filesStorageMapper.deleteFilesStorageById(id);
    }
}
